@@ -426,7 +426,7 @@ function fill_fin_data(text,li)
 /**
  *@brief show the ipopup window and display the details of a card,
  * to work some attribute must be set
- *@parameter obj.qcode is the qcode, obj.nohistory if you don't want to  display
+ *@param obj.qcode is the qcode, obj.nohistory if you don't want to  display
  * the history button, obj.ro is the popin is readonly
  *@note you must the gDossier as hidden in the calling page
  *
@@ -607,7 +607,7 @@ function select_card_type(obj)
  *        - filter is the filter but with a  fd_id list, -1 means there  is no filter
  *        - ref : reload the window after adding card
  *        - content : name of the div
- *@example dis_blank_card({gDossier:15,fd_id:12,ref:1});
+ *@note dis_blank_card({gDossier:15,fd_id:12,ref:1});
  *@see ajax_card.php
  */
 function dis_blank_card(obj)
@@ -917,4 +917,4 @@ function action_remove_concerned(p_dossier,p_fiche_id,p_action_id)
             }
     );
     }
-    
\ No newline at end of file
+    
