@@ -30,6 +30,9 @@ require_once NOALYSS_INCLUDE.'/class/class_periode.php';
 html_page_start($_SESSION['g_theme']);
 echo '<div style="float:left;">';
 global $g_user;
+$g_user->Check();
+$g_user->check_dossier(Dossier::id());
+
 if ( basename($_GET['op']) == 'history' )
   {
     $href=dossier::get();
