@@ -3,7 +3,7 @@
 //see licence.txt
 
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once NOALYSS_INCLUDE.'/class_anc_balance_simple.php';
+require_once NOALYSS_INCLUDE.'/class/class_anc_balance_simple.php';
 $bs = new Anc_Balance_Simple($cn);
 $bs->get_request();
 echo '<form method="get">';
