@@ -24,14 +24,15 @@ $result=HtmlInput::default_value_request('result',null);
 
 if ($result != null)
 {
-    $result=$grandLivre->display_html();
+    $grandLivre->load();
     if ($grandLivre->has_data != 0 )
     {
         echo '<span style="display:block">';
           echo _('Tout sélectionner')." ".ICheckBox::toggle_checkbox('export_pdf_bt1','export_anc_receipt_pdf');
         echo '</span>';
         echo $grandLivre->show_button();
-        echo '<form method="GET" id="export_anc_receipt_pdf" action="export.php" style="display:inline">';
+        printf ('<form method="GET" id="export_anc_receipt_pdf" action="export.php" style="display:inline" onsubmit="smoke.signal(\'%s\', function(e){}, {duration: 3000,classname: \'custom-class\'});return true;">',
+                _("Le traitement est en cours ,  merci de patienter sans recharger la page"));
 
         echo $grandLivre->button_export_pdf();
         echo $grandLivre->display_html();
