@@ -75,6 +75,12 @@ $input_from->user=$g_user;
 echo _('Depuis').' :'.$input_from->input();
 // filter on the current year
 $to=HtmlInput::default_value_get("to_periode", "");
+
+if( $to == "") {
+     $t_periode=new Periode($cn);
+     list($per_max,$per_min)=$t_periode->get_limit($exercice);
+     $to=$per_min->p_id;
+}
 $input_to=new IPeriod("to_periode",$to,$exercice);
 $input_to->show_start_date=false;
 $input_to->filter_year=true;
@@ -317,6 +323,7 @@ if ( isset($_GET['view'] ) )
     $lvl3_old='';
 
     bcscale(2);
+    $nb_row = count($row);
     foreach ($row as $r)
     {
         $i++;
@@ -337,7 +344,7 @@ if ( isset($_GET['view'] ) )
 	    if ( ${'lvl'.$ind.'_old'} != mb_substr($r['poste'],0,$ind))
 	      {
 
-		echo '<tr >';
+		echo '<tr class="highlight">';
 		echo td(${'lvl'.$ind.'_old'},'style="font-weight:bold;"');
 		echo td(${'lvl'.$ind.'_old'}." "._("Total niveau")." ".$ind,'style="font-weight:bold;"');
                 if ($previous==1) {
@@ -373,6 +380,10 @@ if ( isset($_GET['view'] ) )
 	      $lvl2[$a]=bcadd($lvl2[$a],$r[$a]);
 	      $lvl3[$a]=bcadd($lvl3[$a],$r[$a]);
 	    }
+       // For the Total row , there is no accounting
+        if ( $r['poste'] == "") {
+            $tr="highlight";
+        }
         echo '<TR class="'.$tr.'">';
         echo td($view_history);
         echo td(h($r['label']));
