@@ -78,7 +78,7 @@ if ( isset ($_POST['save_plugin'])){
                 }
                 try
                 {
-                    $a_plugin[$i]->insert_profile_menu($profile,'EXT');
+                    $a_plugin[$i]->insert_profile_menu($profile);
                 }
                 catch (Exception $exc)
                 {
@@ -105,7 +105,8 @@ if ( isset ($_POST['save_plugin'])){
 <div class="content">
     <?php echo _('Nombre de plugins trouvés')." ".$nb_plugin; ?>
     <form method="post">
-    <table class="result">
+    <?php echo _('Filtre');echo " ";echo HtmlInput::filter_table("plugin_install_tb", '0,1,2,3', 1);?>
+    <table id="plugin_install_tb" class="result">
         <tr>
             <th><?php echo _('Extension')?></th>
             <th><?php echo _('Menu')?></th>
@@ -133,7 +134,12 @@ if ( isset ($_POST['save_plugin'])){
                 <?php echo h($a_plugin[$e]->me_menu); ?>
             </td>
             <td>
-                <?php echo h($a_plugin[$e]->me_description); ?>
+                <?php echo h($a_plugin[$e]->me_description);?>
+                <span style="display:block">
+                <?php 
+                    printf(_("Installé par défaut dans %s"),$a_plugin[$e]->depend);
+                ?>
+                </span>
             </td>
             <td>
                 <?php echo h($a_plugin[$e]->me_file); ?>
