@@ -69,7 +69,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
          */
         check_parameter($p_array,'p_jrn,e_date,e_client');
 
-        extract ($p_array);
+        extract ($p_array, EXTR_SKIP);
         /* check if we can write into this ledger */
         if ( $g_user->check_jrn($p_jrn) != 'W' )
             throw new Exception (_('Accès interdit'),20);
@@ -89,7 +89,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             throw new Exception(_('Date invalide'), 2);
         }
         $oPeriode=new Periode($this->db);
-        if ( $this->check_periode() == false)
+        if ( $this->check_periode() == false || ! isset($p_array['period']))
         {
             $tperiode=$oPeriode->find_periode($e_date);
         }
@@ -484,7 +484,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
     public function insert($p_array=null)
     {
         global $g_parameter;
-        extract ($p_array);
+        extract ($p_array, EXTR_SKIP);
         $this->verify($p_array) ;
 
         $group=$this->db->get_next_seq("s_oa_group"); /* for analytic */
@@ -511,7 +511,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
         $oPeriode=new Periode($this->db);
         $check_periode=$this->check_periode();
 
-        if ( $check_periode == true )
+        if ( $check_periode == true && isset($p_array['period']) )
             $tperiode=$period;
         else
             $tperiode=$oPeriode->find_periode($e_date);
@@ -709,7 +709,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             $acc_operation=new Acc_Operation($this->db);
             $acc_operation->date=$e_date;
             $acc_operation->poste=$poste;
-            $acc_operation->amount=$cust_amount-$tot_tva_reversed;
+            $acc_operation->amount=bcsub($cust_amount,$tot_tva_reversed);
             $acc_operation->grpt=$seq;
             $acc_operation->jrn=$p_jrn;
             $acc_operation->type='c';
@@ -748,8 +748,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                     if ( $oTva->get_parameter("both_side")==1)
                     {
                         $poste_vat=$oTva->get_side('c');
-                        $cust_amount=bcadd($tot_amount,$tot_tva);
-                        $cust_amount=bcsub($tot_amount,$tot_tva_reversed);
+                        
                         $acc_operation=new Acc_Operation($this->db);
                         $acc_operation->date=$e_date;
                         $acc_operation->poste=$poste_vat;
@@ -847,7 +846,8 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                 {
                     $poste_val=$sposte;
                 }
-
+                // remove the VAT autoliquidation
+                $cust_amount=bcsub($cust_amount, $tot_tva_reversed);
                 $famount=bcsub($cust_amount,$acompte);
                 $acc_pay->poste=$poste_val;
                 $acc_pay->qcode=$fqcode;
@@ -961,7 +961,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
     public function input($p_array=null,$p_readonly=0)
     {
         global $g_parameter,$g_user;
-        if ( $p_array != null ) extract($p_array);
+        if ( $p_array != null ) extract($p_array, EXTR_SKIP);
 
         $flag_tva=$g_parameter->MY_TVA_USE;
         /* Add button */
@@ -1733,7 +1733,7 @@ EOF;
     }
     /**
      * Retrieve data from the view v_detail_purchase
-     * @global  $g_user connected user
+     * @note  $g_user connected user
      * @param $p_from jrn.jr_tech_per from 
      * @param $p_end jrn.jr_tech_per to
      * @return handle to database result
