@@ -68,7 +68,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
         if (is_array($p_array ) == false || empty($p_array))
                     throw new Exception ("Array empty");
         
-        extract($p_array);
+        extract($p_array, EXTR_SKIP);
         
         /*
          * Check needed value
@@ -93,7 +93,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
         }
 
         $oPeriode = new Periode($this->db);
-        if ($this->check_periode() == true) {
+        if ($this->check_periode() == true && isset($p_array['period'])) {
             $tperiode = $period;
             /* check that the datum is in the choosen periode */
             $oPeriode->p_id = $period;
@@ -157,7 +157,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
         // foreach item
         //----------------------------------------
         for ($i = 0; $i < $nb_item; $i++) {
-            if (strlen(trim(${'e_march' . $i})) == 0)
+            if (! isset (${'e_march' . $i}) || strlen(trim(${'e_march' . $i})) == 0)
                 continue;
             /* check if amount are numeric and */
             if (isNumber(${'e_march' . $i . '_price'}) == 0)
@@ -226,13 +226,13 @@ class Acc_Ledger_Sold extends Acc_Ledger {
      * * It generates the document if gen_invoice is set and save the middle of payment if any ($e_mp)
      *
      * \param $p_array is usually $_POST or a predefined operation
-     * \return string
+     * \return string : internal number 
      * \note throw an Exception
      */
 
     public function insert($p_array = null) {
         global $g_parameter;
-        extract($p_array);
+        extract($p_array, EXTR_SKIP);
         $this->verify($p_array);
 
         $group = $this->db->get_next_seq("s_oa_group"); /* for analytic */
@@ -244,7 +244,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
         $oPeriode = new Periode($this->db);
         $check_periode = $this->check_periode();
 
-        if ($check_periode == true)
+        if ($check_periode == true && isset($p_array['period']))
             $tperiode = $period;
         else
             $tperiode = $oPeriode->find_periode($e_date);
@@ -607,7 +607,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
 
     function confirm($p_array, $p_summary = false) {
         global $g_parameter;
-        extract($p_array);
+        extract($p_array, EXTR_SKIP);
 
         // don't need to verify for a summary
         if (!$p_summary)
@@ -1003,7 +1003,7 @@ EOF;
     function input($p_array = null, $p_readonly = 0) {
         global $g_parameter, $g_user;
         if ($p_array != null)
-            extract($p_array);
+            extract($p_array, EXTR_SKIP);
 
         $flag_tva = $g_parameter->MY_TVA_USE;
         /* Add button */
@@ -1312,7 +1312,7 @@ EOF;
     }
     /**
      * Retrieve data from the view v_detail_sale
-     * @global  $g_user connected user
+     * @remark  $g_user connected user
      * @param $p_from jrn.jr_tech_per from 
      * @param type $p_end jrn.jr_tech_per to
      * @return type
