@@ -47,6 +47,7 @@ class Anc_Balance_Double extends Anc_Print
 
     function display_html ()
     {
+        bcscale(2);
         $r="";
 
         $array=$this->load();
@@ -77,7 +78,8 @@ class Anc_Balance_Double extends Anc_Print
                 {
 		  $r.="<tr>".td('');
 		  $r.="<td>Total </td>".td(nbm($tot_deb),' class="num"').td(nbm($tot_cred),' class="num"');
-                    $s=abs($tot_deb-$tot_cred);
+                    $s=abs(bcsub($tot_deb,$tot_cred));
+                    
                     $d=($tot_deb>$tot_cred)?'debit':'credit';
                     $r.="<td class=\"num\">".nbm($s)."</td><td>$d</td>";
                     $r.="</tr>";
@@ -103,8 +105,8 @@ class Anc_Balance_Double extends Anc_Print
 		$r.= '<tr>';
 		$r.=td('');
             }
-            $tot_deb+=$row['a_d'];
-            $tot_cred+=$row['a_c'];
+            $tot_deb=bcadd($tot_deb,$row['a_d']);
+            $tot_cred=bcadd($tot_cred,$row['a_c']);
 
 	    $r.=td($row['b_po_name']." ".$row['b_po_description']);
 
@@ -144,7 +146,7 @@ class Anc_Balance_Double extends Anc_Print
             $r.='<td>'.$row['desc'].'</td>';
             $r.='<td class="num">'.nbm($row['debit']).'</td>';
             $r.='<td class="num">'.nbm($row['credit']).'</td>';
-	    $diff=bcsub($row['debit'],$row['credit']);
+	    $diff=bcsub($row['credit'],$row['debit']);
 	    $tot_cred=bcadd($tot_cred,$row['credit']);
 	    $tot_deb=bcadd($tot_deb,$row['debit']);
 
@@ -157,7 +159,7 @@ class Anc_Balance_Double extends Anc_Print
 	$r.=td('total');
 	$r.=td(nbm($tot_deb),'class="num"');
 	$r.=td(nbm($tot_cred),'class="num"');
-	$solde=bcsub($tot_deb,$tot_cred);
+	$solde=bcsub($tot_cred,$tot_deb);
 	$sign=($tot_cred<$tot_deb)?" - ":" + ";
 	$r.=td($sign.nbm($solde),'class="num" style="border:solid 1px blue;font-weight:bold"');
 	$r.='</tr>';
@@ -173,6 +175,7 @@ class Anc_Balance_Double extends Anc_Print
     function display_pdf()
     {
         $array=$this->load();
+        bcscale(2);
         if (empty($array))return;
         $pdf=new PDF($this->db);
         $pdf->Setdossierinfo(dossier::name());
@@ -186,7 +189,7 @@ class Anc_Balance_Double extends Anc_Print
         $pb=new Anc_Plan($this->db,$this->pa_id2);
         $pb->get();
         $pdf->SetFont('DejaVu','B',9);
-        $pdf->Cell(0,7,sprintf("Balance croise plan %s %s ",
+        $pdf->write_cell(0,7,sprintf("Balance croise plan %s %s ",
                                $pa->name,
                                $pb->name),1,0,'C');
         $filtre_date="";
@@ -208,59 +211,76 @@ class Anc_Balance_Double extends Anc_Print
                                ($this->to_poste2!="")?"jusque ".$this->to_poste2:"");
 
         $pdf->SetFont('DejaVu','',8);
-        $pdf->Cell(50,7,$filtre_date);
-        $pdf->Cell(50,7,$filtre_pa);
-        $pdf->Cell(50,7,$filtre_pb);
-        $pdf->Ln();
+        $pdf->write_cell(50,7,$filtre_date);
+        $pdf->write_cell(50,7,$filtre_pa);
+        $pdf->write_cell(50,7,$filtre_pb);
+        $pdf->line_new();
 
         $pdf->SetFont('DejaVu','',6);
-        $pdf->Cell(20,7,'id','B');
-        $pdf->Cell(100,7,'Poste Comptable','B');
-        $pdf->Cell(20,7,'Débit','B',0,'L');
-        $pdf->Cell(20,7,'Crédit','B',0,'L');
-        $pdf->Cell(20,7,'Solde','B',0,'L');
-        $pdf->Cell(20,7,'D/C','B',0,'L');
-        $pdf->Ln();
+        $pdf->write_cell(20,7,'id','B');
+        $pdf->write_cell(100,7,'Poste Comptable','B');
+        $pdf->write_cell(20,7,'Débit','B',0,'L');
+        $pdf->write_cell(20,7,'Crédit','B',0,'L');
+        $pdf->write_cell(20,7,'Solde','B',0,'L');
+        $pdf->write_cell(20,7,'D/C','B',0,'L');
+        $pdf->line_new();
 
         for ($i=0;$i<count($array);$i++)
         {
             $row=$array[$i];
-            $pdf->Cell(20,6,$row['a_po_name'],0,0,'L');
-            $pdf->Cell(40,6,mb_substr($row['a_po_description'],0,31),0,0,'L');
-            $pdf->Cell(20,6,$row['b_po_name'],0,0,'L');
-            $pdf->Cell(40,6,mb_substr($row['b_po_description'],0,31),0,0,'L');
-            $pdf->Cell(20,6,$row['a_d'],0,0,'R');
-            $pdf->Cell(20,6,$row['a_c'],0,0,'R');
-            $pdf->Cell(20,6,$row['a_solde'],0,0,'R');
-            $pdf->Cell(20,6,$row['a_debit'],0,0,'C');
-            $pdf->Ln();
+            $pdf->write_cell(20,6,$row['a_po_name'],0,0,'L');
+            $pdf->write_cell(40,6,mb_substr($row['a_po_description'],0,31),0,0,'L');
+            $pdf->write_cell(20,6,$row['b_po_name'],0,0,'L');
+            $pdf->write_cell(40,6,mb_substr($row['b_po_description'],0,31),0,0,'L');
+            $pdf->write_cell(20,6,$row['a_d'],0,0,'R');
+            $pdf->write_cell(20,6,$row['a_c'],0,0,'R');
+            $side=($row['a_c']>$row['a_d'])?"+":"-";
+            $side=($row['a_c'] == $row['a_d'])?"=":$side;
+            $pdf->write_cell(20,6,$side." ".$row['a_solde'],0,0,'R');
+            $pdf->write_cell(20,6,$row['a_debit'],0,0,'C');
+            $pdf->line_new();
         }
 
         $sum=$this->show_sum($array);
         $pdf->SetFont('DejaVu','B',8);
-        $pdf->Cell(70,6,'Somme',1,0,'C');
-        $pdf->Ln(5);
+        $pdf->write_cell(70,6,'Somme',1,0,'C');
+        $pdf->line_new(5);
         $pdf->SetFont('DejaVu','',6);
 
-        $pdf->Cell(20,7,'Poste');
-        $pdf->Cell(60,7,'Description','B');
-        $pdf->Cell(20,7,'Débit','B',0,'L');
-        $pdf->Cell(20,7,'Crédit','B',0,'L');
-        $pdf->Cell(20,7,'Solde','B',0,'L');
-        $pdf->Cell(20,7,'D/C','B',0,'L');
-        $pdf->Ln();
-
+        $pdf->write_cell(20,7,'Poste');
+        $pdf->write_cell(60,7,'Description','B');
+        $pdf->write_cell(20,7,'Débit','B',0,'L');
+        $pdf->write_cell(20,7,'Crédit','B',0,'L');
+        $pdf->write_cell(20,7,'Solde','B',0,'L');
+        $pdf->write_cell(20,7,'D/C','B',0,'L');
+        $pdf->line_new();
+        // Summary
+        $tot_cred=$tot_deb=0;
         for ($i=0;$i<count($sum);$i++)
         {
             $row=$sum[$i];
-            $pdf->Cell(20,6,$row['poste'],0,0,'L');
-            $pdf->Cell(60,6,$row['desc'],0,0,'L');
-            $pdf->Cell(20,6,sprintf('%.2f',$row['debit']),0,0,'R');
-            $pdf->Cell(20,6,sprintf('%.2f',$row['credit']),0,0,'R');
-            $pdf->Cell(20,6,sprintf('%.2f',$row['solde']),0,0,'R');
-            $pdf->Cell(20,6,$row['dc'],0,0,'R');
-            $pdf->Ln();
+            $pdf->write_cell(20,6,$row['poste'],0,0,'L');
+            $pdf->write_cell(60,6,$row['desc'],0,0,'L');
+            $pdf->write_cell(20,6,sprintf('%.2f',$row['debit']),0,0,'R');
+            $pdf->write_cell(20,6,sprintf('%.2f',$row['credit']),0,0,'R');
+            $side=($row['credit']>$row['debit'])?"+":"-";
+            $side=($row['debit'] == $row['credit'])?"=":$side;
+            $pdf->write_cell(20,6,sprintf($side." ".'%.2f',$row['solde']),0,0,'R');
+            $pdf->write_cell(20,6,$row['dc'],0,0,'R');
+            $pdf->line_new();
+            $tot_cred=bcadd($tot_cred,$row['credit']);
+            $tot_deb=bcadd($tot_deb,$row['debit']);
         }
+        $pdf->write_cell(20,6,"",0,0,'L');
+        $pdf->write_cell(60,6,_('Total'),0,0,'L');
+        $pdf->write_cell(20,6,nb($tot_deb),0,0,'R');
+        $pdf->write_cell(20,6,nb($tot_cred),0,0,'R');
+        $side=($tot_cred > $tot_deb)?"+":"-";
+        $side=($tot_deb == $tot_cred)?"=":$side;
+        $solde=abs(bcsub($tot_cred,$tot_deb));
+        $pdf->write_cell(20,6,$side." ".$solde,0,0,'R');
+        $pdf->write_cell(20,6,$row['dc'],0,0,'R');
+        $pdf->line_new();
         $fDate=date('dmy-Hi');
         $pdf->output('crossbalance-'.$fDate.'.pdf','D');
     }
@@ -480,7 +500,7 @@ class Anc_Balance_Double extends Anc_Print
             $a[$count]['a_po_description']=$row['a_po_description'];
             $a[$count]['b_po_name']=$row['b_po_name'];
             $a[$count]['b_po_description']=$row['b_po_description'];
-            $a[$count]['a_solde']=abs($row['a_d']-$row['a_c']);
+            $a[$count]['a_solde']=abs($row['a_c']-$row['a_d']);
             $a[$count]['a_debit']=($row['a_d']>$row['a_c'])?"debit":"credit";
 
             $count++;
