@@ -536,7 +536,7 @@ class Anc_Operation
     function display_form_plan($p_array,$p_null,$p_mode,$p_seq,$p_amount,$p_id='',$p_add_button=true)
     {
         if ( $p_array != null)
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
         $result="";
         $plan=new Anc_Plan($this->db);
         $a_plan=$plan->get_list(" order by pa_id ");
@@ -660,7 +660,7 @@ class Anc_Operation
     function save_form_plan_vat_nd($p_array,$p_item,$p_j_id,$p_nd)
     {
         bcscale(4);
-        extract($p_array);
+        extract($p_array, EXTR_SKIP);
 	if (! isset ($hplan) ) return;
         
         if ( ! isset(${'amount_t'.$p_item}) )
@@ -746,7 +746,7 @@ class Anc_Operation
      */
     function save_form_plan($p_array,$p_item,$p_j_id)
     {
-        extract($p_array);
+        extract($p_array, EXTR_SKIP);
 	if (! isset ($hplan) ) return;
         /* variable for in array
            pa_id array of existing pa_id
@@ -755,11 +755,11 @@ class Anc_Operation
            op contains sequence
            p_item is used to identify what op is concerned
         */
-        /* echo "j_id = $j_id p_item = $p_item hplan=".var_export($hplan[$p_item],true)." val = ".var_export($val[$p_item],true).'<br>'; */
         /* for each row */
-        //   for ($i=0;$i<count($val[$p_item]);$i++) {
         $idx_pa_id=0;
         $row=0;
+        
+        if ( ! isset ($hplan[$p_item]))            return;
         // foreach col PA
         for ($e=0;$e<count($hplan[$p_item]);$e++)
         {
@@ -799,7 +799,7 @@ class Anc_Operation
     */
     function save_update_form($p_array)
     {
-        extract($p_array);
+        extract($p_array, EXTR_SKIP);
         if ( ! isset($opanc)) return;
         for ($i = 0; $i < count($opanc); $i++)
         {
@@ -901,10 +901,11 @@ class Anc_Operation
      */
     function delete_by_jid($p_jid)
     {
-        $sql="delete from operation_analytique where j_id=$p_jid";
-        $this->db->exec_sql($sql);
+        $sql="delete from operation_analytique where j_id=$1";
+        $this->db->exec_sql($sql,array($p_jid));
     }
-    /*\brief Display a table with analytic accounting in
+    /*!
+     *\brief Display a table with analytic accounting in
      *       detail of operation
      *@note $this->j_id must be set
      *\param $p_mode 0 = readonly or 1=writable
