@@ -63,25 +63,32 @@ class Document
         $this->db->exec_sql($sql);
 
     }
-	function compute_filename($pj,$filename)
-	{
-		foreach (array('/','*','<','>',';',',','\\','.',':') as $i) {
-			$pj= str_replace($i, "-",$pj);
-		}
-		// save the suffix
-		$pos_prefix=strrpos($filename,".");
-		if ($pos_prefix == 0) $pos_prefix=strlen($filename);
-		$filename_no=substr($filename,0,$pos_prefix);
-		$filename_suff=substr($filename,$pos_prefix,strlen($filename));
-		$new_filename=  strtolower($filename_no."-".$pj.$filename_suff);
-		return $new_filename;
-	}
+    /**
+     * Insert the receipt number into the filename , each generated file
+     * will have the name of the template (model) + receipt number)
+     * @param type $pj the receipt number
+     * @param type $filename the name of the file
+     * @return string
+     */
+    function compute_filename($pj,$filename)
+    {
+            foreach (array('/','*','<','>',';',',','\\','.',':','(',')',' ','[',']') as $i) {
+                    $pj= str_replace($i, "-",$pj);
+            }
+            // save the suffix
+            $pos_prefix=strrpos($filename,".");
+            if ($pos_prefix == 0) $pos_prefix=strlen($filename);
+            $filename_no=substr($filename,0,$pos_prefix);
+            $filename_suff=substr($filename,$pos_prefix,strlen($filename));
+            $new_filename=  strtolower($filename_no."-".$pj.$filename_suff);
+            return $new_filename;
+    }
     /*!
      * \brief Generate the document, Call $this-\>Replace to replace
      *        tag by value
      *@param p_array contains the data normally it is the $_POST
-     *@param contains the new filename
-     * \return an array : the url where the generated doc can be found, the name
+     *@param $p_filename contains the new filename
+     * \return an string : the url where the generated doc can be found, the name
      * of the file and his mimetype
      */
     function Generate($p_array,$p_filename="")
@@ -828,13 +835,13 @@ class Document
              *  - [DATE_LIMIT]
              */
         case 'DATE_LIMIT_CALC':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $id='e_ech' ;
             if ( !isset (${$id}) ) return "";
             $r=format_date(${$id},'DD.MM.YYYY','YYYY-MM-DD');
             break;
       case 'DATE_LIMIT':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $id='e_ech' ;
             if ( !isset (${$id}) ) return "";
             $r=${$id};
@@ -845,7 +852,7 @@ class Document
             break;
 
         case 'VEN_ART_NAME':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $id='e_march'.$this->counter;
             // check if the march exists
             if ( ! isset (${$id})) return "";
@@ -859,7 +866,7 @@ class Document
             else $r = "";
             break;
        case 'VEN_ART_LABEL':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $id='e_march'.$this->counter."_label";
             // check if the march exists
 
@@ -885,7 +892,7 @@ class Document
                     $r=${'e_march'.$this->counter.'_label'};
             break;
         case 'VEN_ART_STOCK_CODE':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
                     $id = 'e_march' . $this->counter;
                     // check if the march exists
                     if (!isset(${$id}))
@@ -903,7 +910,7 @@ class Document
                     }
             break;
         case 'VEN_ART_PRICE':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $id='e_march'.$this->counter.'_price' ;
             if ( !isset (${$id}) ) return "";
 			if (${$id} == 0 ) return "";
@@ -912,7 +919,7 @@ class Document
 
         case 'TVA_RATE':
         case 'VEN_ART_TVA_RATE':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $id='e_march'.$this->counter.'_tva_id';
             if ( !isset (${$id}) ) return "";
             if ( ${$id} == -1 || ${$id}=='' ) return "";
@@ -926,7 +933,7 @@ class Document
 
         case 'TVA_CODE':
         case 'VEN_ART_TVA_CODE':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $id='e_march'.$this->counter.'_tva_id';
             if ( !isset (${$id}) ) return "";
             if ( ${$id} == -1 ) return "";
@@ -941,7 +948,7 @@ class Document
             break;
 
         case 'TVA_LABEL':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $id='e_march'.$this->counter.'_tva_id';
             if ( !isset (${$id}) ) return "";
             $march_id='e_march'.$this->counter.'_price' ;
@@ -956,7 +963,7 @@ class Document
             /* total VAT for one sold */
         case 'TVA_AMOUNT':
         case 'VEN_TVA':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $qt='e_quant'.$this->counter;
             $price='e_march'.$this->counter.'_price' ;
             $tva='e_march'.$this->counter.'_tva_id';
@@ -973,7 +980,7 @@ class Document
             /* TVA automatically computed */
         case 'VEN_ART_TVA':
         
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $qt='e_quant'.$this->counter;
             $price='e_march'.$this->counter.'_price' ;
             $tva='e_march'.$this->counter.'_tva_id';
@@ -990,7 +997,7 @@ class Document
             break;
 
         case 'VEN_ART_TVAC':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $qt='e_quant'.$this->counter;
             $price='e_march'.$this->counter.'_price' ;
             $tva='e_march'.$this->counter.'_tva_id';
@@ -1014,7 +1021,7 @@ class Document
             break;
 
         case 'VEN_ART_QUANT':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $id='e_quant'.$this->counter;
             if ( !isset (${$id}) ) return "";
             // check that something is sold
@@ -1027,7 +1034,7 @@ class Document
             break;
 
         case 'VEN_HTVA':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $id='e_march'.$this->counter.'_price' ;
             $quant='e_quant'.$this->counter;
             if ( !isset (${$id}) ) return "";
@@ -1043,7 +1050,7 @@ class Document
             break;
 
         case 'VEN_TVAC':
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $id='e_march'.$this->counter.'_tva_amount' ;
             $price='e_march'.$this->counter.'_price' ;
             $quant='e_quant'.$this->counter;
@@ -1063,7 +1070,7 @@ class Document
             break;
 
         case 'TOTAL_VEN_HTVA':
-            extract($p_array);
+            extract($p_array, EXTR_SKIP);
 			bcscale(4);
             $sum=0.0;
             for ($i=0;$i<$nb_item;$i++)
@@ -1085,7 +1092,7 @@ class Document
             $r=round($sum,2);
             break;
         case 'TOTAL_VEN_TVAC':
-            extract($p_array);
+            extract($p_array, EXTR_SKIP);
             $sum=0.0;
 			bcscale(4);
             for ($i=0;$i<$nb_item;$i++)
@@ -1107,7 +1114,7 @@ class Document
 
             break;
         case 'TOTAL_TVA':
-            extract($p_array);
+            extract($p_array, EXTR_SKIP);
             $sum=0.0;
             for ($i=0;$i<$nb_item;$i++)
             {
