@@ -18,7 +18,7 @@
 */
 
 // Copyright Author Dany De Bontridder danydb@aevalys.eu
-
+require_once NOALYSS_INCLUDE.'/class/class_pdf_operation.php';
 /**
  * @brief Export DOCUMENT from Analytic accountancy, can transform into PDF
  * and add a stamp on each pages
@@ -93,10 +93,24 @@ class Document_Export
         header('Pragma: public');
         echo file_get_contents($this->store_pdf . '/result.pdf');
     }
-
+    /**
+     * @brief remove folder and its content
+     */
     function clean_folder()
     {
+        $files=  scandir($this->store_convert);
+        $nb_file=count($files);
+        for ($i=0;$i < $nb_file;$i++) {
+            if (is_file($this->store_convert."/".$files[$i])) unlink($this->store_convert."/".$files[$i]);
+        }
         rmdir($this->store_convert);
+        $files=  scandir($this->store_pdf);
+        $nb_file=count($files);
+        for ($i=0;$i < $nb_file;$i++) {
+            if (is_file($this->store_pdf."/".$files[$i])) unlink($this->store_pdf."/".$files[$i]);
+        }
+        rmdir($this->store_pdf);
+        
     }
 
     /**
@@ -120,25 +134,25 @@ class Document_Export
             if ($file[0]['jr_pj'] == '')
                 continue;
 
-            $cn->lo_export($file[0]['jr_pj'], $this->store_convert . '/' . $file[0]['jr_pj_name']);
+            $filename=clean_filename($file[0]['jr_pj_name']);
+            $cn->lo_export($file[0]['jr_pj'], $this->store_convert . '/' . $filename);
 
             // Convert this file into PDF 
             if ($file[0]['jr_pj_type'] != 'application/pdf')
             {
                 $status = 0;
-                $arg=" ".escapeshellarg($this->store_convert.DIRECTORY_SEPARATOR.$file[0]['jr_pj_name']);
+                $arg=" ".escapeshellarg($this->store_convert.DIRECTORY_SEPARATOR.$filename);
                 echo "arg = [".$arg."]";
                 passthru(OFFICE . " " . $arg , $status);
                 if ($status <> 0)
                 {
-                    $this->feedback[$cnt_feedback]['file'] = $file[0]['jr_pj_name'];
+                    $this->feedback[$cnt_feedback]['file'] = $filename;
                     $this->feedback[$cnt_feedback]['message'] = ' cannot convert to PDF';
                     $this->feedback[$cnt_feedback]['error'] = $status;
                     $cnt_feedback++;
                     continue;
                 }
             } 
-
             // Create a image with the stamp + formula
             $img = imagecreatefromgif(NOALYSS_INCLUDE . '/template/template.gif');
             $font = imagecolorallocatealpha($img, 100, 100, 100, 110);
@@ -162,8 +176,8 @@ class Document_Export
 
             // 
             // remove extension
-            $ext = strrpos($file[0]['jr_pj_name'], ".");
-            $file_pdf = substr($file[0]['jr_pj_name'], 0, $ext);
+            $ext = strrpos($filename, ".");
+            $file_pdf = substr($filename, 0, $ext);
             $file_pdf .=".pdf";
             
             //-----------------------------------
@@ -198,13 +212,12 @@ class Document_Export
             }
             // output
             $output = $this->store_convert . '/stamp_' . $file_pdf;
-
+            
             // Concatenate stamp + file
             $stmt = PDFTK . " " . escapeshellarg($this->store_convert . '/' . $file_pdf) . ' stamp ' . $this->store_convert .
                     '/stamp.pdf output ' . $output;
-            
+
             passthru($stmt, $status);
-            echo $stmt;
             if ($status <> 0)
             {
 
@@ -214,17 +227,47 @@ class Document_Export
                 $cnt_feedback++;
                 continue;
             }
+            
+            // create the pdf with the detail of operation
+            $detail_operation = new PDF_Operation($cn,$value);
+            $detail_operation->export_pdf(array("acc","anc"));
+
+            // output 2
+            $output2 = $this->store_convert . '/operation_' . $file_pdf;
+            
+            // concatenate detail operation with the output
+            $stmt = PDFTK . " " . $detail_operation->get_pdf_filename()." ".$output. 
+                    ' output ' . $output2;
+
+            passthru($stmt, $status);
+            if ($status <> 0)
+            {
+
+                $this->feedback[$cnt_feedback]['file'] = $file_pdf;
+                $this->feedback[$cnt_feedback]['message'] = _('Echec Ajout detail ');
+                $this->feedback[$cnt_feedback]['error'] = $status;
+                $cnt_feedback++;
+                continue;
+            }
+            // remove doc with detail
+            $detail_operation->unlink();
+            
+            // overwrite old with new PDF
+            rename ($output2,$output);
+            
             // Move the PDF into another temp directory 
             $this->move_file($output, 'stamp_' . $file_pdf);
         }
+        
+        // concatenate all pdf into one
         $this->concatenate_pdf();
+        
         ob_clean();
         $this->send_pdf();
 
         // remove files from "conversion folder"
         $this->clean_folder();
         
-        // concatenate all pdf into one
     }
    /**
     * @brief check that the files are installed
