@@ -553,7 +553,7 @@ class Fiche
                 array($this->id));
         $ret="";
         $ret.=h2(_("Catégorie")." ".$type_card, 'style="display:inline"');
-        $ret.='<span style="font-weight:bolder;margin-right:5px;float:right">'.
+        $ret.='<span style="margin-right:5px;float:right">'.
                 _('id fiche').':'.$this->id."</span>";
         $ret.="<table style=\"width:98%;margin:1%\">";
         if (empty($attr))
@@ -1682,8 +1682,8 @@ class Fiche
     function get_categorie()
     {
         if ( $this->id == 0 ) throw  new Exception('class_fiche : f_id = 0 ');
-        $sql='select fd_id from fiche where f_id='.$this->id;
-        $R=$this->cn->get_value($sql);
+        $sql='select fd_id from fiche where f_id=$1';
+        $R=$this->cn->get_value($sql, array($this->id));
         if ( $R == "" )
             $this->fd_id=0;
         else
@@ -1846,7 +1846,7 @@ class Fiche
     function build_sql($array)
     {
         if (!empty($array))
-            extract($array);
+            extract($array, EXTR_SKIP);
         $and='';
         $filter_fd_id='true';
         $filter_query='';
