@@ -81,6 +81,8 @@ class Periode
             return 1;
         return 0;
     }
+    ///Return 1 if the periode is open otherwise 0
+    //!\note For only a ledger you must set Periode::jrn_def_id to the ledger id
     function is_open()
     {
         /* if jrn_Def_id == 0 then we check the global otherwise we check
@@ -99,6 +101,8 @@ class Periode
             return 1;
         return 0;
     }
+    ///Return 1 if periode is centralized
+    //!\note deprecated , centralization not used anymore
     function is_centralized()
     {
         if ( $this->jrn_def_id != 0 )
@@ -138,7 +142,9 @@ class Periode
         }
 
     }
-
+    ///Close a periode , if Periode::jrn_def_id is set to a different value
+    /// than 0 , it close only for this ledger id ; otherwise close for all 
+    /// periode
     function close()
     {
         if ( $this->jrn_def_id == 0 )
@@ -541,7 +547,7 @@ class Periode
 	  for ($i=1;$i < 12;$i++)
 	    {
 	      $date_start=sprintf('01.%02d.%d',$i,$p_exercice);
-	      $date_end=$this->cn->get_value("select to_char(to_date('$date_start','DD.MM.YYYY')+interval '1 month'-interval '1 day','DD.MM.YYYY')");
+	      $date_end=$this->cn->get_value("select to_char(to_date($1,'DD.MM.YYYY')+interval '1 month'-interval '1 day','DD.MM.YYYY')",array($date_start));
 	      if ( $this->insert($date_start,$date_end,$p_exercice) != 0)
 		{
 		  throw new Exception('Erreur insertion période');
@@ -553,8 +559,10 @@ class Periode
 	    }
 	  if ( $nb_periode==13)
 	    {
-	      if ($this->insert('01.12.'.$p_exercice,'30.12.'.$p_exercice,$p_exercice) != 0 ) 	      throw new Exception('Erreur insertion période');
-	      if ($this->insert('31.12.'.$p_exercice,'31.12.'.$p_exercice,$p_exercice) != 0 ) 	      throw new Exception('Erreur insertion période');
+	      if ($this->insert('01.12.'.$p_exercice,'30.12.'.$p_exercice,$p_exercice) != 0 ) 	   
+                      throw new Exception('Erreur insertion période');
+	      if ($this->insert('31.12.'.$p_exercice,'31.12.'.$p_exercice,$p_exercice) != 0 ) 	     
+                      throw new Exception('Erreur insertion période');
 	    }
 
 
