@@ -133,8 +133,6 @@ if ( isset($_POST['correct']))
 //----------------------------------------
 // Blank form
 //----------------------------------------
-echo '<div style="position:absolute" class="content">';
-
 echo '<p class="notice">'.$p_msg.'</p>';
 
 echo '<form class="print" name="form_detail" enctype="multipart/form-data" class="print" METHOD="POST">';
@@ -151,7 +149,7 @@ try
     echo HtmlInput::submit('save',_('Sauve'));
     echo HtmlInput::reset(_('Effacer'));
 
-    if ( ! isset ($_POST['e_date'])&& $g_parameter->MY_DATE_SUGGEST=='Y')
+    if ( ! isset($_REQUEST['e_date'])&& $g_parameter->MY_DATE_SUGGEST=='Y')
     {
             echo create_script(" get_last_date();ajax_saldo('first_sold');");
     }else {
