@@ -465,7 +465,7 @@ function sql_string($p_string)
 }
 
 /**
-  /* \brief store the string which print
+* \brief store the string which print
  *           the content of p_array in a table
  *           used to display the menu
  * \param  $p_array array like ( 0=>HREF reference, 1=>visible item (name),2=>Help(opt),
@@ -475,7 +475,7 @@ function sql_string($p_string)
  * \param $class_ref CSS for the A tag
  * \param $default selected item
  * \param $p_extra extra code for the table tag (CSS or javascript)
- *
+ */
   /* \return : string */
 
 function ShowItem($p_array, $p_dir='V', $class="mtitle", $class_ref="mtitle", $default="", $p_extra="")
@@ -561,10 +561,18 @@ function echo_warning($p_string)
 
 function getPeriodeName($p_cn, $p_id, $pos='p_start')
 {
-    if ($pos != 'p_start' and
-	    $pos != 'p_end')
-	echo_error('lib/ac_common.php' . "-" . __LINE__ . '  UNDEFINED PERIODE');
-    $ret = $p_cn->get_value("select to_char($pos,'Mon YYYY') as t from parm_periode where p_id=$p_id");
+    if ($pos != 'p_start' &&  $pos != 'p_end')
+    {
+        echo_error('lib/ac_common.php' . "-" . __LINE__ . '  UNDEFINED PERIODE');
+        throw new Exception(_("paramètre invalide"));
+    }
+    if ( isNumber($p_id) == 0 )
+	{
+	throw new Exception("Paramètre invalide");
+	return;
+	}
+    $ret = $p_cn->get_value("select to_char($pos,'Mon YYYY') as t from parm_periode where p_id=$1", 
+           array( $p_id));
     return $ret;
 }
 
@@ -582,7 +590,7 @@ function getPeriodeName($p_cn, $p_id, $pos='p_start')
 function getPeriodeFromMonth($p_cn, $p_date)
 {
     $R = $p_cn->get_value("select p_id from parm_periode where
-                        to_char(p_start,'DD.MM.YYYY') = '01.$p_date'");
+                        to_char(p_start,'DD.MM.YYYY') = $1", array('01.'.$p_date));
     if ($R == "")
 	return -1;
     return $R;
@@ -620,6 +628,9 @@ function sql_filter_per($p_cn, $p_from, $p_to, $p_form='p_id', $p_field='jr_tech
 	echo_error(__FILE__, __LINE__, 'Mauvais parametres ');
 	exit(-1);
     }
+    $p_from=  sql_string($p_from);
+    $p_to=  sql_string($p_to);
+    $p_field=  sql_string($p_field);
     if ($p_form == 'p_id')
     {
 	// retrieve the date
@@ -897,7 +908,7 @@ function show_module($selected)
 }
 /**
  * Find the default module or the first one
- * @global $g_user $g_user
+ * @var $g_user $g_user
  * @return default module (string)
  */
 function find_default_module()
@@ -976,7 +987,7 @@ function find_default_module()
 
 /**
  * show the module
- * @global $g_user
+ * @var $g_user
  * @param $module the $_REQUEST['ac'] exploded into an array
  * @param  $idx the index of the array : the AD code is splitted into an array thanks the slash
  */
@@ -1223,9 +1234,9 @@ function get_array_column($p_array,$key)
  */
 function factory_Ledger(Database &$p_cn, $ledger_id)
 {
-    include_once 'class/class_acc_ledger_sold.php';
-    include_once 'class/class_acc_ledger_purchase.php';
-    include_once 'class/class_acc_ledger_fin.php';
+    include_once NOALYSS_INCLUDE.'/class/class_acc_ledger_sold.php';
+    include_once NOALYSS_INCLUDE.'/class/class_acc_ledger_purchase.php';
+    include_once NOALYSS_INCLUDE.'/class/class_acc_ledger_fin.php';
     
     $ledger=new Acc_Ledger($p_cn, $ledger_id);
     $type=$ledger->get_type();
@@ -1263,4 +1274,4 @@ function is_msie()
         $is_msie=0;
     return $is_msie;
 }
-?>
\ No newline at end of file
+?>
