@@ -20,13 +20,15 @@
 
 // Copyright Author Dany De Bontridder danydb@aevalys.eu
 
-/**\file
+/**
+ * \file
  * \brief contains the class for connecting to a postgresql database
  */
 require_once NOALYSS_INCLUDE.'/constant.php';
 require_once NOALYSS_INCLUDE.'/lib/ac_common.php';
 
-/**\brief
+/**
+ * \brief
  * This class allow you to connect to the postgresql database, execute sql, retrieve data
  *
  */
@@ -45,7 +47,7 @@ class Database
 
     function __construct($p_database_id=0, $p_type='dos')
     {
-        if (IsNumber($p_database_id)==false||strlen($p_database_id)>5)
+        if (IsNumber($p_database_id)==false||strlen($p_database_id)>10)
             die("-->Dossier invalide [$p_database_id]");
         $noalyss_user=(defined("noalyss_user"))?noalyss_user:phpcompta_user;
         $password=(defined("noalyss_password"))?noalyss_password:phpcompta_password;
@@ -105,6 +107,8 @@ class Database
             else
             {
                 echo '<h2 class="error">Erreur de connexion !</h2>';
+                $this->is_open=false;
+                return;
             }
         }
         $this->db=$a;
@@ -138,6 +142,11 @@ class Database
     {
         pg_set_client_encoding($this->db, $p_charset);
     }
+    function get_encoding()
+    {
+        return pg_client_encoding($this->db);
+    }
+
 
     /**
      * \brief send a sql string to the database
@@ -200,7 +209,8 @@ class Database
         return $this->ret;
     }
 
-    /** \brief Count the number of row returned by a sql statement
+    /** 
+     * \brief Count the number of row returned by a sql statement
      *
      * \param $p_sql sql string
      * \param $p_array if not null we use the safer pg_query_params
@@ -212,7 +222,8 @@ class Database
         return pg_NumRows($r_sql);
     }
 
-    /**\brief get the current sequence value
+    /**
+     * \brief get the current sequence value
      */
 
     function get_current_seq($p_seq)
@@ -221,7 +232,8 @@ class Database
         return $Res;
     }
 
-    /**\brief  get the next sequence value
+    /**
+     * \brief  get the next sequence value
      */
 
     function get_next_seq($p_seq)
@@ -232,7 +244,7 @@ class Database
     }
 
     /**
-     * @ brief : start a transaction
+     * @brief : start a transaction
      *
      */
     function start()
@@ -582,12 +594,29 @@ class Database
     {
         $r=$this->exec_sql($p_sql, $p_array);
 
-        if (($Max=pg_NumRows($r))==0)
+        if (pg_NumRows($r)==0)
             return array();
         $array=pg_fetch_all($r);
         return $array;
     }
-
+    /**
+     * Returns only one row from a query
+     * @param string $p_sql
+     * @param array $p_array
+     * @return array , idx = column of the table or null if nothing is found
+     * @throws Exception if too many rows are found code 100
+     */
+    function get_row($p_sql,$p_array=NULL) {
+        $array=$this->get_array($p_sql,$p_array);
+        if (empty($array) ) return null;
+        if (count($array)==1) return $array[0];
+        throw new Exception("Database:get_row retourne trop de lignes",100);
+    }
+    /**
+     * @brief Create a sequence
+     * @param string $p_name Sequence Name
+     * @param int $min starting value
+     */
     function create_sequence($p_name, $min=1)
     {
         if ($min<1)
@@ -609,7 +638,8 @@ class Database
         return true;
     }
 
-    /**\brief test if a table exist
+    /**
+     * \brief test if a table exist
      * \param $p_name table name
      * \param  $schema name of the schema default public
      * \return true if a table exist otherwise false
@@ -680,7 +710,7 @@ class Database
      */
     function exist_blob($p_oid)
     {
-        $r=$this->get_value('select count(loid) from pg_largeobject where loid=$1'
+        $r=$this->get_value('select count(*) from pg_largeobject_metadata where oid=$1'
                 , array($p_oid));
         if ($r>0)
             return true;
@@ -949,6 +979,7 @@ class Database
 
     function lo_unlink($p_oid)
     {
+        if ( ! $this->exist_blob($p_oid)) return;
         return pg_lo_unlink($this->db, $p_oid);
     }
 
@@ -963,7 +994,8 @@ class Database
         return pg_prepare($this->db, $p_string, $p_sql);
     }
 
-    /**\brief wrapper for the function pg_execute
+    /**
+     * \brief wrapper for the function pg_execute
      * \param $p_string string name of the stmt given in pg_prepare function
      * \param $p_array contains the variables
      * \note set this->ret to the return of pg_execute
@@ -976,7 +1008,8 @@ class Database
         return $this->ret;
     }
 
-    /**\brief wrapper for the function pg_lo_export
+    /**
+     * \brief wrapper for the function pg_lo_export
      * \param $p_oid is the oid of the log
      * \param $tmp  is the file
      * \return result of the operation
@@ -1123,4 +1156,4 @@ class Database
 
 }
 
-/* test::test_me(); */
\ No newline at end of file
+/* test::test_me(); */
