@@ -64,9 +64,9 @@ class HtmlInput
     var $disabled;                  /*!<  $disabled poss. value == true or nothing, to disable INPUT*/
     var $extra;                     /*!<  $extra different usage, it depends of the $type */
     var $extra2;                    /*!<  $extra2 different usage,
-        									it depends of the $type */
-    var $javascript;				   /*!< $javascript  is the javascript to add to the widget */
-    var $ctrl;						/*!<$ctrl is the control to update (see js_search_card_control) */
+                                            it depends of the $type */
+    var $javascript;                /*!< $javascript  is the javascript to add to the widget */
+    var $ctrl;			/*!<$ctrl is the control to update (see js_search_card_control) */
 
     var $tabindex;
     function __construct($p_name="",$p_value="",$p_id="")
@@ -81,6 +81,7 @@ class HtmlInput
         $this->table=0;
         $this->disabled=false;
         $this->javascript="";
+        $this->extra="";
         $this->extra2="all";
         $this->attribute=array();
         $this->id=$p_id;
@@ -132,6 +133,7 @@ class HtmlInput
      * @return javascript string with the object
      * @note: there is not check on the key->value, so you could need to escape
      * special char as quote, single-quote...
+     * @deprecated 
      * @code
     $a=new IButton()
     $a->set_attribute('prop','1');
@@ -143,7 +145,7 @@ class HtmlInput
     echo $string => {'prop':'1','prop2':'2','prop3':'3'};
     @endcode
     */
-    public function make_object($p_name=null)
+    public function make_object_deprecated($p_name=null)
     {
         $name=($p_name != null)?$p_name.'=':'';
         if ( count($this->attribute) == 0) return $name."{}";
@@ -465,6 +467,19 @@ class HtmlInput
 		$r.='<input type="button" id="'.$id.'" class="'.$p_class.'" onclick="'.$javascript.'" value="'.h($action).'">';
 		return $r;
 
+    }
+    /**
+     * Image to click , 
+     * @param string $p_image filename of the image under image/
+     * @param string $p_js javascript when the image is clicked
+     * @param string $p_message Message 
+     */
+    static  function image_click($p_image,$p_js,$p_message)
+    {
+        $ret=sprintf('<a class="nav" style="display:inline" href="#" title="%s"><img src="image/%s" onclick="%s"></a>',
+                $p_message,$p_image,$p_js);
+        return $ret;
+
     }
     /**
      * button Html image
@@ -550,6 +565,18 @@ class HtmlInput
 
       return $r;
     }
+    /**
+     * @brief transform a json to hidden 
+     * @param json $p_json
+     */
+    static function json_to_hidden($p_json)
+    {
+        $aJson=json_decode($p_json);
+        foreach($aJson as $key=>$value) 
+        {
+            echo HtmlInput::hidden($key, $value);
+        }
+    }
     /**
      *transform $_GET   data  to hidden
      *@param $array is an of indices
@@ -786,7 +813,8 @@ class HtmlInput
       /**
        *Create an ISelect object containing the available repository for reading
        * or writing
-       * @global $g_user
+       * @remark $g_user global.
+       *
        * @param $p_cn db object
        * @param $p_name name of the select
        * @param $p_mode is 'R' for reading, 'W' for writinh
@@ -873,7 +901,7 @@ class HtmlInput
          */
         static function button_choice_ledger($p_array)
         {
-            extract ($p_array);
+            extract ($p_array, EXTR_SKIP);
             $bledger_param = json_encode(array(
                 'dossier' => $_REQUEST['gDossier'],
                 'type' => $type,
@@ -906,9 +934,8 @@ class HtmlInput
             echo '</span>';
         }
         /**
-         * Returns HTML code for displaying a icon with a link to a receipt document from
+         * @brief Returns HTML code for displaying a icon with a link to a receipt document from
          * the ledger 
-         * @global $cn database connx
          * @param $p_jr_id jrn.jr_id
          * @param $p_name name in the link , if the name is empty then we show the icon
          * @return nothing or HTML Code for a link to the document
