@@ -43,7 +43,7 @@ if ( $g_user->check_jrn($ledger->id)=='X')
 	alert(_("Vous ne pouvez pas écrire dans ce journal, contacter votre administrateur"));
 	return;
 }
-echo '<div style="position:absolute" class="content">';
+echo '<div class="content">';
 echo '<div id="predef_form">';
 echo HtmlInput::hidden('p_jrn_predef', $ledger->id);
 $op = new Pre_op_ods($cn);
@@ -61,7 +61,7 @@ echo '</div>';
 // Show the predef operation
 // Don't forget the p_jrn
 $p_post=$_POST;
-if ( isset ($_GET['action']) && ! isset($_POST['correct']))
+if ( isset ($_GET['action']) && ! isset($_POST['correct']) && ! isset($correct) )
 {
 	if ( $_GET['action']=='use_opd')
 	{
@@ -77,7 +77,7 @@ if ( isset ($_GET['action']) && ! isset($_POST['correct']))
 }
 $p_msg=(isset($p_msg))?$p_msg:"";
 print '<p class="notice">'.$p_msg.'</p>';
-echo '<form method="post"  class="print">';
+echo '<form method="post"  class="print" onsubmit="return controleBalance();" >';
 echo dossier::hidden();
 echo HtmlInput::request_to_hidden(array('ac'));
 
@@ -108,7 +108,7 @@ echo '</form>';
 echo "<script>checkTotalDirect();</script>";
 echo create_script(" update_name()");
 
-if ($g_parameter->MY_DATE_SUGGEST=='Y')
+if (!isset($_REQUEST['e_date']) && $g_parameter->MY_DATE_SUGGEST=='Y')
 {
 	echo create_script(" get_last_date()");
 }
