@@ -131,9 +131,11 @@ if ( isset ($_REQUEST['sa'] ))
         }
         $new_cn=new Database($id);
 
-        $new_cn->apply_patch($name,0);
+        $new_cn->apply_patch($name);
         echo '<span class="error">'._('Ne pas recharger la page, sinon votre base de données sera restaurée une fois de plus').'</span>';
 	Dossier::synchro_admin($id);
+        User::remove_inexistant_user($id);
+        $new_cn->clean_orphan_lob();
         echo $retour;
 
         echo '</div>';
@@ -149,16 +151,16 @@ if ( isset ($_REQUEST['sa'] ))
         $id=$cn->get_next_seq('s_modid');
 
         if ( strlen(trim($_REQUEST['database'])) == 0 )
-            $lname=$id." Restauration :".sql_string($_FILES['file']['name']);
+            $lname=$id." Restauration :".$_FILES['file']['name'];
         else
             $lname=$id." ".$_REQUEST['database'];
-
-
-        $sql="insert into modeledef (mod_id,mod_name,mod_desc) values (".$id.",'Restauration".$lname."','".$ldesc."') ";
+        
+        $ldesc=HtmlInput::default_value_post("desc", "");
+        $sql="insert into modeledef (mod_id,mod_name,mod_desc) values ($1,$2,$3)";
         $cn->start();
         try
         {
-            $cn->get_value($sql);
+            $cn->exec_sql($sql,array($id,$lname,$ldesc));
 
         }
         catch ( Exception $e)
@@ -191,8 +193,8 @@ if ( isset ($_REQUEST['sa'] ))
 
         $new_cn=new Database($id,'mod');
 
-        $new_cn->apply_patch($name,0);
-
+        $new_cn->apply_patch($name);
+        $new_cn->clean_orphan_lob();
         echo '<span class="error">'._('Ne pas recharger la page, sinon votre base de données sera restaurée une fois de plus').'</span>';
         echo $retour;
 
