@@ -27,7 +27,7 @@
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
 global $cn,$g_parameter,$g_user;
-require_once NOALYSS_INCLUDE.'/class_stock.php';
+require_once NOALYSS_INCLUDE.'/class/class_stock.php';
 
 // Show the form
 // Get by exercice
@@ -47,7 +47,7 @@ $presentation->value=array (
 		array("value"=>"L","label"=>"Liste")
 );
 $presentation->selected=(isset($_GET['present']))?$_GET['present']:"T";
-require_once NOALYSS_INCLUDE.'/template/stock_state_search.php';
+require_once NOALYSS_TEMPLATE.'/stock_state_search.php';
 
 $stock=new Stock($cn);
 
