@@ -1,20 +1,20 @@
 <?php
 
 /*
- *   This file is part of PhpCompta.
+ *   This file is part of NOALYSS.
  *
- *   PhpCompta is free software; you can redistribute it and/or modify
+ *   NOALYSS isfree software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
  *
- *   PhpCompta is distributed in the hope that it will be useful,
+ *   NOALYSS isdistributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with PhpCompta; if not, write to the Free Software
+ *   along with NOALYSS; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 // Copyright (2014) Author Dany De Bontridder <dany@alchimerys.be>
@@ -71,6 +71,8 @@ if ($sb === "upg_all" && (!defined('MULTI')||(defined('MULTI')&&MULTI==1)))
             $db=new Database($db_row['dos_id'], 'dos');
             $db->apply_patch($db_row['dos_name']);
             Dossier::synchro_admin($db_row['dos_id']);
+            User::remove_inexistant_user($db_row['dos_id']);
+            $db->clean_orphan_lob();
         }
         else
         {
@@ -95,6 +97,7 @@ if ($sb === "upg_all" && (!defined('MULTI')||(defined('MULTI')&&MULTI==1)))
         {
             $db=new Database($db_row['mod_id'], 'mod');
             $db->apply_patch($db_row['mod_name']);
+            $db->clean_orphan_lob();
         }
         else
         {
