@@ -91,12 +91,12 @@ echo HtmlInput::button_action(_("Fermer"), "$('create_user').style.display='none
     <script>
         function check_form() {
             if ($F('input_login') == "") { 
-                    alert('<?php echo _('Le login ne peut être vide') ?>');
+                    smoke.alert('<?php echo _('Le login ne peut être vide') ?>');
                     $('input_login').setStyle({border:"red solid 2px"});
                     return false;
                 }
             if ($F('input_password') == "") { 
-                alert('<?php echo _('Le mot de passe ne peut être vide') ?>');
+                smoke.alert('<?php echo _('Le mot de passe ne peut être vide') ?>');
                 $('input_password').setStyle({border:"red solid 2px"});
                 return false;
             }
@@ -168,9 +168,13 @@ if ( !empty ($a_user) )
         echo td($r_user['use_name']);
         echo td($r_user['use_first_name']);
         echo td($Active);
-		$type=($r_user['use_admin']==1)?_("Administrateur"):_("Utilisateur");
-		echo "<td>".$type."</td>";
-		echo td($r_user['ag_dossier']);
+        $type=($r_user['use_admin']==1)?_("Administrateur"):_("Utilisateur");
+        echo "<td>".$type."</td>";
+        if ( $r_user['use_admin'] == 0)
+            echo td($r_user['ag_dossier']);
+        else {
+            echo td(_('Tous'));
+        }
         echo '</tr>';
     }// foreach
     echo '</table>';
