@@ -90,7 +90,16 @@ else if ($sbaction == "delete")
     $cn = new Database();
     $Res = $cn->exec_sql("delete from jnt_use_dos where use_id=$1", array($uid));
     $Res = $cn->exec_sql("delete from ac_users where use_id=$1", array($uid));
-
+    //------------------------------------
+    // Remove user from all the dossiers
+    //------------------------------------
+    $a_dossier=$cn->get_array('select dos_id from ac_dossier');
+    if ( is_array($a_dossier) ) {
+        $nb=count($a_dossier);
+        for ( $i=0;$i<$nb;$i++)
+            User::remove_inexistant_user($a_dossier[$i]['dos_id']);
+    }
+    
     echo "<center><H2 class=\"info\"> Utilisateur " . h($_POST['fname']) . " " . h($_POST['lname']) . " est effacé</H2></CENTER>";
     require_once NOALYSS_INCLUDE.'/lib/class_iselect.php';
     require_once NOALYSS_INCLUDE.'/user.inc.php';
